@@ -28,8 +28,6 @@ class SaltCliFactory(_SaltCliFactory):
     def process_output(self, stdout, stderr, cmdline=None):
         if "No minions matched the target. No command was sent, no jid was assigned.\n" in stdout:
             stdout = stdout.split("\n", 1)[1:][0]
-        old_stdout = None
         if cmdline and "--show-jid" in cmdline and stdout.startswith("jid: "):
-            old_stdout = stdout
             stdout = stdout.split("\n", 1)[-1].strip()
         return super().process_output(stdout, stderr, cmdline=cmdline)
