@@ -61,9 +61,9 @@ class FactoriesManager:
             can be written down to disk.
         start_timeout(int):
             The amount of time, in seconds, to wait, until a subprocess is considered as not started.
-        stats_processes(:py:class:`~collections.OrderedDict`):
-            This will be an `OrderedDict` instantiated on the :py:func:`~_pytest.hookspec.pytest_sessionstart`
-            hook accessible at `stats_processes` on the `session` attribute of the :fixture:`request`.
+        stats_processes(:py:class:`saltfactories.plugins.sysstats.StatsProcesses`):
+            This will be an `StatsProcesses` class instantiated on the :py:func:`~_pytest.hookspec.pytest_sessionstart`
+            hook accessible as a session scoped `stats_processes` fixture.
         system_install(bool):
             If true, the daemons and CLI's are run against a system installed salt setup, ie, the default
             salt system paths apply.
@@ -97,7 +97,7 @@ class FactoriesManager:
             self.root_dir = pathlib.Path("/")
         if self.start_timeout is None:
             if not sys.platform.startswith(("win", "darwin")):
-                self.start_timeout = 30
+                self.start_timeout = 60
             else:
                 # Windows and macOS are just slower
                 self.start_timeout = 120
